@@ -3,25 +3,26 @@
 # April 2009
 
 wtest<-function(cases,offset,data,alpha=0.05){
-  attach(data,warn.conflicts = FALSE)
+  xcases=with(data,get(cases)) # replace attach
+  xoffset=with(data,get(offset)) # replace attach
   j<-(0:11)/12
-  N=sum(cases)
-  M=sum(offset)
-  W=sum(sqrt(cases))
+  N=sum(xcases)
+  M=sum(xoffset)
+  W=sum(sqrt(xcases))
 # observed values
-  c=sqrt(cases)*cos(j*2*pi)
+  c=sqrt(xcases)*cos(j*2*pi)
   cbar=sum(c/W)
-  s=sqrt(cases)*sin(j*2*pi)
+  s=sqrt(xcases)*sin(j*2*pi)
   sbar=sum(s/W)
   d=sqrt( (cbar^2) + (sbar^2) )
 # expected values
-  D=sum(sqrt(offset))
-  c=sqrt(offset)*cos(j*2*pi)
+  D=sum(sqrt(xoffset))
+  c=sqrt(xoffset)*cos(j*2*pi)
   Ecbar=sum(c/D)
-  s=sqrt(offset)*sin(j*2*pi)
+  s=sqrt(xoffset)*sin(j*2*pi)
   Esbar=sum(s/D)
 # variance	
-  D=sum(sqrt(N*offset/M))
+  D=sum(sqrt(N*xoffset/M))
   c=cos(j*2*pi)*cos(j*2*pi)
   Vc=0.25*sum(c)/(D^2)
   s=sin(j*2*pi)*sin(j*2*pi)
@@ -34,6 +35,5 @@ wtest<-function(cases,offset,data,alpha=0.05){
   pvalue<-1-pchisq(test,df=2)
   cat('Walter`s test\n')
   cat('test statistic',test,'p-value',pvalue,'\n')
-  detach(data)
   return(list(test=test,pvalue=pvalue))
 }
